Getting Started
===============

PauliCirc is a library for the creation of circuits of Pauli gadgets.

Installation
------------

You can install the latest release from `PyPI <https://pypi.org/project/tensorsat/>`_ as follows:

.. code-block:: console

    $ pip install --upgrade paulicirc

GitHub repo: https://github.com/neverlocal/paulicirc
